#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Author  : xinfa.jiang
# @File    : simple_server.py

from fastapi import APIRouter
from fastapi import Request
from pythonnote.config import templates

simple_router = APIRouter()


@simple_router.get('/')
async def index(request: Request):
    return templates.TemplateResponse("index.html", {"request": request, "message": 'Easy Python'})


@simple_router.get('/help')
async def help(request: Request):
    return templates.TemplateResponse("help.html", {"request": request, "message": 'Easy Python'})


@simple_router.get('/about')
async def about(request: Request):
    return templates.TemplateResponse("about.html", {"request": request, "message": 'Easy Python'})


@simple_router.get('/addview')
async def index(request: Request):
    return templates.TemplateResponse("add_file.html", {"request": request, "message": 'Easy Python'})



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Author  : xinfa.jiang
# @File    : code_all_in_map.py

def get_file_read(path: str):
    pycode = open(path, encoding='utf-8').read()
    return pycode





#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Author  : xinfa.jiang
# @File    : utils.py
import os
from pythonnote.config import code_dir, code_md_dir


def add_file_txt_count(file_path):
    count = 0
    try:
        with open(file_path, encoding='utf-8', mode='r') as f:
            txt = f.read()
            txt = txt.replace('\n', '').strip()
            count = int(txt)
    except:
        count = 0
    count += 1
    with open(file_path, encoding='utf-8', mode='w') as f:
        f.write(str(count))


def get_file_txt_count(file_path):
    count = 0
    try:
        with open(file_path, encoding='utf-8', mode='r') as f:
            txt = f.read()
            txt = txt.replace('\n', '').strip()
            count = int(txt)
    except:
        count = 0
    return count


def del_file(path):
    os.remove(path)


def get_all_code_name_map(code_dir=code_dir, code_md_dir=code_md_dir):
    code_name_map = {}
    code_name_map['root'] = ('root', code_dir, code_md_dir)
    for fname in os.listdir(code_dir):
        if '.py' not in fname:
            continue
        name = fname[:-3]
        path = os.path.join(code_dir, fname)
        md_path = os.path.join(code_md_dir, name + '.md')
        code_name_map[name] = (name, path, md_path)
    return code_name_map


def load_data():
    code_name_map = get_all_code_name_map()

    code_name_list = []
    for i, name in enumerate(sorted(code_name_map)):
        name, _, _ = code_name_map[name]
        if name == 'root':
            continue
        title = ' '.join(name.split('_'))
        code_name_list.append([name, str(i + 1) + ' : ' + title])
    code_name_list = sorted(code_name_list)
    return code_name_map, code_name_list



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Author  : xinfa.jiang
# @File    : config.py
import os
from fastapi.staticfiles import StaticFiles
from fastapi.templating import Jinja2Templates

root_path = os.path.dirname(__file__)
code_dir = os.path.join(root_path, 'pythonnotes')
code_md_dir = os.path.join(root_path, 'pythonnote_md')

web_path = os.path.join(root_path, 'web')
logs_path = os.path.join(root_path, 'logs')
s_path = os.path.join(web_path, 'static')
statics = StaticFiles(directory=s_path)

#  python ide
python_path = os.path.join(web_path, 'codemirror_python')
python_statics = StaticFiles(directory=python_path)

#  python js running
python_rpath = os.path.join(web_path, 'Skulpt')
python_rstatics = StaticFiles(directory=python_rpath)
# python_rtemplates = Jinja2Templates(directory=python_rpath)

# other
templates = Jinja2Templates(directory=os.path.join(web_path, 'templates'))

count_day = os.path.join(logs_path, 'count_day.txt')
count_view_code = os.path.join(logs_path, 'count_view_code.txt')



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Author  : xinfa.jiang
# @File    : server.py
import os
from fastapi import APIRouter

from fastapi import Request
from pythonnote.config import templates
import pythonnote.web.code_util as code_util
from pythonnote.web.Items import Item
import pythonnote.web.utils as utils
import pythonnote.config as config

router = APIRouter()

code_name_map, code_name_list = utils.load_data()


def remove_name(name):
    global code_name_map, code_name_list
    del code_name_map[name]

    ci = None
    for ci in code_name_list:
        if ci[0] == name:
            break
    if ci is not None:
        code_name_list.remove(ci)


@router.get('/view')
async def view(request: Request):
    count_day = utils.get_file_txt_count(config.count_day)
    count_view_code = utils.get_file_txt_count(config.count_view_code)
    data = {
        'all_num': len(code_name_list),
        'count_day': count_day,
        'count_view_code': count_view_code,
        'code_name_list': code_name_list
    }
    return templates.TemplateResponse("code_list.html", {"request": request, "data": data, "message": "Python List"})


@router.get('/filter_view/{keyword}')
async def view(request: Request, keyword: str = 'L'):
    count_day = utils.get_file_txt_count(config.count_day)
    count_view_code = utils.get_file_txt_count(config.count_view_code)
    f_code_name_list = [ni for ni in code_name_list if keyword in ni[1]]
    data = {
        'all_num': len(code_name_list),
        'count_day': count_day,
        'count_view_code': count_view_code,
        'code_name_list': f_code_name_list
    }
    return templates.TemplateResponse("code_list.html", {"request": request, "data": data, "message": "Python List"})


@router.get('/code/{name}')
async def view_code(request: Request, name: str = '001_Two_Sum'):
    global code_name_map
    if name not in code_name_map:
        return templates.TemplateResponse("index.html", {"request": request, "message": 'Easy Python'})
    # 代码路径
    code_path = code_name_map[name][1]
    # 代码markdwon路径
    code_md_path = code_name_map[name][2]
    code_str = code_util.get_file_read(code_path)
    code_md_str = code_util.get_file_read(code_md_path)
    data = {
        'code_str': code_str,
        'code_md_str': code_md_str,
        'name': name,
    }
    # every times view code,path config.count_view_code 's count +=1 (view code count log)
    utils.add_file_txt_count(config.count_view_code)
    return templates.TemplateResponse("python_index.html", {"request": request, "data": data})


@router.put('/save')
async def save(item: Item):
    global code_name_map
    name = item.name
    # python code
    code_str = item.code_str
    # python code's Markdown note
    code_md_str = item.code_md_str
    # python code's path
    code_path = code_name_map[name][1]
    # python code's Markdown note 's path
    code_md_path = code_name_map[name][2]
    if code_str is not None:
        with open(code_path, 'w', encoding='utf-8') as of:
            of.write(code_str)
    if code_md_str is not None:
        with open(code_md_path, 'w', encoding='utf-8') as of:
            of.write(code_md_str)
    return {
        'status': 'success',
        'name': name
    }


@router.put('/delete')
async def delete(item: Item):
    global code_name_map
    name = None
    try:
        name = item.name
        # python code's path
        code_path = code_name_map[name][1]
        # python code's Markdown note 's path
        code_md_path = code_name_map[name][2]
        remove_name(name)
        utils.del_file(code_path)
        utils.del_file(code_md_path)
        return {
            'status': 'success',
            'name': name
        }
    except Exception as e:
        print(e)
    return {
        'status': 'error',
        'name': name
    }


@router.put('/add')
async def add_file(item: Item):
    global code_name_map, code_name_list
    name = item.name.strip().replace(' ', '_')
    code_str = item.code_str
    code_md_str = item.code_md_str
    if name not in code_name_map:
        code_path = os.path.join(code_name_map['root'][1], name + '.py')
        code_md_path = os.path.join(code_name_map['root'][2], name + '.md')
    else:
        return {
            'status': 'error:file exist !',
            'name': name
        }

    if code_str is None:
        code_str = "print('" + name + "')"
    if code_str is not None:
        with open(code_path, 'w', encoding='utf-8') as of:
            of.write(code_str)
    if code_md_str is None:
        code_md_str = "# " + name
    if code_md_str is not None:
        with open(code_md_path, 'w', encoding='utf-8') as of:
            of.write(code_md_str)

    code_name_map, code_name_list = utils.load_data()
    return {
        'status': 'success',
        'name': name
    }


@router.get('/md/{name}')
async def view_md(request: Request, name: str = '001_Two_Sum'):
    global code_name_map
    if name not in code_name_map:
        return templates.TemplateResponse("index.html", {"request": request, "message": 'Easy Python'})
    # 代码markdwon路径
    code_md_path = code_name_map[name][2]
    code_md_str = code_util.get_file_read(code_md_path)
    data = {
        'code_md_str': code_md_str,
        'name': name,
    }
    return templates.TemplateResponse("md.html", {"request": request, "data": data, "message": name})



#!/usr/bin/env python
# -*- coding: utf-8 -*-


import uvicorn
from fastapi import FastAPI

import pythonnote.config as config
import pythonnote.web.server as a_server
import pythonnote.web.simple_server as a_simple_server
import pythonnote.web.utils as utils

app = FastAPI()
app.mount("/static", config.statics, name="static")
app.mount("/python_static", config.python_statics, name="python_files")
app.mount("/Skulpt", config.python_rstatics, name="pythonr_static")

app.include_router(a_server.router)
app.include_router(a_simple_server.simple_router)


def run(host="127.0.0.1", port=8080):
    '''

    :param host: host
    :param port: port
    :return:
    '''
    print('your host is :', host)
    print('your port is :', port)

    config.templates.env.variable_start_string = '{['
    config.templates.env.variable_end_string = ']}'

    # every times running,path config.count_day 's count +=1 (running count log)
    utils.add_file_txt_count(config.count_day)
    print('_____running:____')
    print('please web browser', 'http://%s:%s' % (str(host), str(port)))
    uvicorn.run(app=app, host=host, port=port, log_level="error")
    # uvicorn.run(app=app, host=host, port=port)


if __name__ == '__main__':
    run()



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Author  : xinfa.jiang
# @File    : Items.py

from pydantic import BaseModel


class Item(BaseModel):
    name: str
    code_str: str = None
    code_md_str: str = None



#!/usr/bin/env python
# -*- coding:utf-8 -*-


from setuptools import setup, find_packages

with open("README.md", "r", encoding='UTF-8') as fh:
    long_description = fh.read()

setup(
    name="pythonnote",
    version="1.0.1",
    keywords=("pythonnote", 'python'),
    description="Easy study Python on web",
    long_description=long_description,
    long_description_content_type="text/markdown",
    license="MIT Licence",
    url="https://github.com/425776024/pythonnote",
    author="Jiang.XinFa",
    author_email="425776024@qq.com",
    packages=find_packages(),
    include_package_data=True,
    platforms="any",
    install_requires=['uvicorn', 'fastapi', 'pydantic', 'aiofiles', 'jinja2']
)
